'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItemListing = void 0;
const tslib_1 = require("tslib");
const ethers_1 = require("ethers");
const typechain_1 = require("@motif-foundation/listing/dist/typechain");
const _1_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/1.json"));
const _3_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/3.json"));
const _7018_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7018.json"));
const _7019_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7019.json"));
const addresses_1 = require("./addresses");
const utils_1 = require("./utils");
const itemListingAddresses = {
    mainnet: _1_json_1.default.itemListing,
    ropsten: _3_json_1.default.itemListing,
    motif: _7018_json_1.default.itemListing,
    motifTestnet: _7019_json_1.default.itemListing,
};
function sumOfArrVal(arr) {
    let sum = 0;
    arr.map((val) => (sum += val));
    return sum;
}
class ItemListing {
    constructor(signerOrProvider, chainId, itemAddress) {
        this.chainId = chainId;
        this.readOnly = !ethers_1.Signer.isSigner(signerOrProvider);
        this.signerOrProvider = signerOrProvider;
        const network = (0, utils_1.chainIdToNetworkName)(chainId);
        const address = itemListingAddresses[network];
        this.itemListing = typechain_1.ItemListing__factory.connect(address, signerOrProvider);
        if (itemAddress) {
            const parsedItemAddress = (0, utils_1.validateAndParseAddress)(itemAddress);
            this.itemAddress = parsedItemAddress;
        }
        else {
            this.itemAddress = addresses_1.addresses[network].item;
        }
    }
    fetchListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.listings(listingId);
        });
    }
    fetchListingFromTransactionReceipt(receipt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            for (const log of receipt.logs) {
                const description = this.itemListing.interface.parseLog(log);
                if (description.args.listingId && log.address === this.itemListing.address) {
                    return this.fetchListing(description.args.listingId);
                }
            }
            return null;
        });
    }
    createListing(tokenId, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency, tokenAddress = this.itemAddress) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.createListing(tokenId, tokenAddress, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency);
        });
    }
    createMultipleListings(tokenIds, startsAt, duration, listPrices, listType, intermediary, intermediaryFeePercentages, listCurrency, tokenAddress = this.itemAddress) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.createMultipleListings(tokenIds, tokenAddress, startsAt, duration, listPrices, listType, intermediary, intermediaryFeePercentages, listCurrency);
        });
    }
    setListingApproval(listingId, approved) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.setListingApproval(listingId, approved);
        });
    }
    setListingDropApproval(listingId, approved, startsAt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.setListingDropApproval(listingId, approved, startsAt);
        });
    }
    setListingListPrice(listingId, listPrice) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.setListingListPrice(listingId, listPrice);
        });
    }
    createBid(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.itemListing.listings(listingId);
            // If ETH listing, include the ETH in this transaction
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.itemListing.createBid(listingId, amount, { value: amount });
            }
            else {
                return this.itemListing.createBid(listingId, amount);
            }
        });
    }
    endFixedPriceListing(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.itemListing.listings(listingId);
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.itemListing.endFixedPriceListing(listingId, amount, { value: amount });
            }
            else {
                return this.itemListing.endFixedPriceListing(listingId, amount);
            }
        });
    }
    endListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.endListing(listingId);
        });
    }
    cancelListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.itemListing.cancelListing(listingId);
        });
    }
}
exports.ItemListing = ItemListing;
//# sourceMappingURL=ItemListing.js.map