"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMotifProfiles = void 0;
const tslib_1 = require("tslib");
const axios_1 = (0, tslib_1.__importDefault)(require("axios"));
const MOTIF_API_BASE_URL = 'https://motif.foundation';
const MAX_USERS_PER_REQUEST = 100;
/**
 * Returns a list of Motif user profiles given a list of up to 100 addresses
 * @param addresses
 */
function getMotifProfiles(addresses) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        if (addresses.length === 0) {
            throw new Error('Empty addresses array');
        }
        if (addresses.length > MAX_USERS_PER_REQUEST) {
            throw new Error(`Addresses array exceeds max length of ${MAX_USERS_PER_REQUEST}`);
        }
        try {
            const res = yield axios_1.default.post(`${MOTIF_API_BASE_URL}/api/users`, { addresses });
            if (!res.data || !Array.isArray(res.data) || res.data.length === 0) {
                throw new Error();
            }
            return res.data;
        }
        catch (err) {
            let msg;
            if (err.response && err.response.data && typeof err.response.data === 'string') {
                msg = err.response.data;
            }
            else if (err.message) {
                msg = err.message;
            }
            else {
                msg = 'Error retrieving users';
            }
            throw new Error(msg);
        }
    });
}
exports.getMotifProfiles = getMotifProfiles;
//# sourceMappingURL=users.js.map